"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ZIP_PAGES_WAIT_TIME = exports.ProcessDeleteEntriesTasks = void 0;
var _tasks = require("@webiny/tasks");
var _types = require("../../../../types");
const ZIP_PAGES_WAIT_TIME = exports.ZIP_PAGES_WAIT_TIME = 10;
class ProcessDeleteEntriesTasks {
  async execute(params) {
    const {
      response,
      input,
      isAborted,
      isCloseToTimeout,
      context,
      store
    } = params;
    try {
      if (isAborted()) {
        return response.aborted();
      } else if (isCloseToTimeout()) {
        return response.continue({
          ...input
        });
      }
      const result = await context.tasks.listTasks({
        where: {
          parentId: store.getTask().id,
          definitionId: _types.EntriesTask.DeleteTrashBinEntries,
          taskStatus_in: [_tasks.TaskDataStatus.RUNNING, _tasks.TaskDataStatus.PENDING]
        },
        limit: 1
      });
      if (result.items.length > 0) {
        return response.continue({
          ...input
        }, {
          seconds: ZIP_PAGES_WAIT_TIME
        });
      }
      return response.done(`Task done: trash bin for the "${input.modelId}" model has been emptied.`);
    } catch (ex) {
      return response.error(ex.message ?? "Error while executing ProcessDeleteEntriesTasks");
    }
  }
}
exports.ProcessDeleteEntriesTasks = ProcessDeleteEntriesTasks;

//# sourceMappingURL=ProcessDeleteEntriesTasks.js.map